@@ -1,5 +1,5 @@
 ### Sunthud Pornprasertmanit & Terrence D. Jorgensen (anyone else?)
-### Last updated: 3 June 2018
+### Last updated: 26 November 2019
 ### Primary engines for simulation.  Everything else is added details.
 
 sim <- function(nRep = NULL, model = NULL, n = NULL, generate = NULL, ...,
@@ -47,13 +47,14 @@ sim <- function(nRep = NULL, model = NULL, n = NULL, generate = NULL, ...,
 			generate <- list(model = generate)
 			lavaanGenerate <- TRUE
 		} else if (is.partable(generate)) {
+			generate$ustart <- generate$start <- generate$est # TDJ added 26 Nov 2019
 			generate <- list(model = generate)
 			lavaanGenerate <- TRUE
 		} else if (is.lavaancall(generate)) {
 			lavaanGenerate <- TRUE
 		} else if (is(generate, "lavaan")) {
 			temp <- parTable(generate)
-			temp$ustart <- temp$est
+			temp$ustart <- temp$start <- temp$est
 			generate <- list(model = temp)
 			lavaanGenerate <- TRUE
 		} else if (is(generate, "MxModel")) {
@@ -78,6 +79,7 @@ sim <- function(nRep = NULL, model = NULL, n = NULL, generate = NULL, ...,
 	lavaanAnalysis <- FALSE
 	mxAnalysis <- FALSE
 	functionAnalysis <- FALSE
+	.om. <- model # TDJ 29 Nov 2019: save original argument, in case needed for generate=NULL
 	if (is.character(model)) {
 		model <- list(model = model)
 		lavaanAnalysis <- TRUE
@@ -104,6 +106,24 @@ sim <- function(nRep = NULL, model = NULL, n = NULL, generate = NULL, ...,
 	if (lavaanAnalysis) {
 		model <- c(model, list(...))
 		if (!("group" %in% names(model)) & "group" %in% names(mc)) model$group <- group
+
+		## TDJ addition (26 Nov 2019):
+		if (is.null(generate)) {
+		  lavaanGenerate <- TRUE
+		  generate <- .om.
+		  ## scroll through options again
+		  if (is.character(generate)) {
+		    generate <- list(model = generate)
+		  } else if (is.partable(generate)) {
+		    generate$ustart <- generate$start <- generate$est
+		    generate <- list(model = generate)
+		  } else if (is(generate, "lavaan")) {
+		    temp <- parTable(generate)
+		    temp$ustart <- temp$start <- temp$est
+		    generate <- list(model = temp)
+		  }
+		}
+		## end TDJ addition
 	}
 
 	if (mxAnalysis) {
@@ -1358,7 +1378,7 @@ reduceMisspecSet <- function(misspecSet, latent, indLab = NULL, facLab = NULL, c
             temp <- c(temp, param)
         }
 
-		if(ngroups > 1) names(temp) <- paste0(g, ".", names(temp))
+		if(ngroups > 1 && length(names(temp))) names(temp) <- paste0(g, ".", names(temp))
 		final <- c(final, temp)
 	}
     final
@@ -1602,8 +1622,8 @@ parsePopulation <- function(paramSet, draws, group = 1, std = FALSE, covData = N
 }
 
 is.partable <- function(object) {
-  ALLNAMES <- c("id","lhs","op","rhs","user","group","free","ustart","exo",
-                "label","plabel","start","est","se","eq.id","unco")
+  ALLNAMES <- c("id","lhs","op","rhs","user","block","group","level","free",
+                "ustart","exo","label","plabel","start","est","se","eq.id","unco")
   # leave eq.id and unco for reverse comptability.
   ## 14 April 2016:  Terry added new names "est" and "se"
 	is.list(object) && all(names(object) %in% ALLNAMES)
